View Source Swoosh.Gallery.Layout (swoosh_gallery v0.2.0)
This is the base layout of the Gallery. This is used both on Swoosh.Gallery.Plug and Mix.Tasks.Swoosh.Gallery.Html.
Summary
Functions
Renders a layout. See template.html.eex to find all the properties used by this.
Functions
Renders a layout. See template.html.eex to find all the properties used by this.